/* Supports automatically extended slot arrays of arbitrary type */


#include <string.h>			/* For memset, memcpy */
#include <stdlib.h>			/* For malloc, free */

#include <evblib/db/slotarray.h>


/* Functions */


int slots_init(SLOTS_T *slots, int size, int count)
{
    slots->size = size;
    slots->count = 0;
    slots->array = 0;
    if (count) {
	slots->array = malloc(count * size);
	if (slots->array) {
	    memset(slots->array, 0, count * size);
	    slots->count = count;
	}
    }
    return 0;
}


void slots_done(SLOTS_T *slots)
{
    if (slots->array) free(slots->array);
    slots->array = 0;
}


int slots_brk(SLOTS_T *slots, int index)
{
    void *newarray;
    int newcount;

    if (index < slots->count) return slots->count;

    /* Allocate new array, copy old one to it and zero the rest */

    newcount = SLOTS_PCTINCREASE(index + 1);
    newarray = malloc(newcount * slots->size);
    if (!newarray) return slots->count;

    memcpy(newarray, slots->array, slots->count * slots->size);
    memset(newarray + slots->count * slots->size, 0, (newcount - slots->count) * slots->size);

    /* Free old array */

    free(slots->array);
    slots->count = newcount;
    slots->array = newarray;

    return slots->count;
}


/*
 * vim:softtabstop=4:sw=4
 */

