
/* This is a header fragment that defines the event process interface. 
   Interfaces such as this one can be used to define a set of function pointers
   or prefixed prototypes.

   To get a set of function pointers for embedding into your own 
   structures, define this before including this file:

     #define F(type, name, args...)	type (*name)( args );

   To define a set of prototypes, where each function is prefixed with the
   prefix 'myevproc_', use:

     #define F(type, name, args...)	type myevproc_##name( args );
*/


/* ep_init initialises an evproc structure. Part of interface to allow derived
   evprocs to provide a version that sets the function pointers as it needs
   them. */

F(void,	ep_init,		struct evproc *ep)

/* ep_addhandles adds any required handles to the handleset given by io_hs */

F(void,	ep_addhandles,		struct evproc *ep, struct handleset *io_hs)

/* ep_handle signals the evproc the possible occurance of an event; it should
   be interpreted as a suggestion to (re)try whatever operation it wanted to
   first get an indication for. 

   Returns 0 if the evproc is done and it need not be considered any longer;
   < 0 if it is done but terminated abnormally, and > 0 otherwise. Should not
   call ep_done itself when it's done; that's left to the user/manager. */

F(int,	ep_handle,		struct evproc *ep, struct handleset *hs)

/* can be used to clean up whatever data is attached to the instance via the
   private member or by deriving from struct evproc. */

F(void,	ep_done,		struct evproc *ep)

